#ifndef __NFS_SECURITY_UTILES_H
#define __NFS_SECURITY_UTILES_H


typedef enum
{
  NSU_OK = 0,
  NSU_ADD_POLICY_ERR,
  NSU_ADD_POLICY_ERR_PERMANENT,
  NSU_ERROR
} error_type;

typedef enum
{
  IMA_POLICY_TYPE = 0,
  FILE_POLICY_TYPE,
  PROCESS_POLICY_TYPE,
  MODULE_POLICY_TYPE,
  NETWORK_POLICY_TYPE,
  INTEGRITY_POLICY_TYPE
} policy_type;

#define NSU_PPRO_WL  0x1
#define NSU_FPRO_WL  0x2
#define NSU_KMODPRO_WL  0x4
#define NSU_NPRO_WL  0x8

int add_to_config(char *rule, int type);
int del_from_config(char *rule, int type);
int add_policy_rule(char *rule, int type);
int del_policy_rule(char *rule, int type);
int clean_policy_rule(int type);
int get_policy_fd(int type);
int open_policy_file(int type);
int close_policy_file(int type);

/*
 * 将一个进程加入到保护列表中，不允许该进程被kill。
 * filename： 进程名
 * permanent： 是否永久，0为关机前加入防杀，1为永久防杀。
 * return NSU_OK表示成功，其他值表示出现错误。
*/
int add_ppro_rule(char *filename, int permanent);
/*
 * 将一个文件加入到保护列表中，不允许修改该文件。
 * filename：  文件路径
 * return NSU_OK表示成功，其他值表示出现错误。
*/
int add_fpro_rule(char *filename);
/*
 * 将一个内核模块加入到保护列表中，不允许该模块被卸载。
 * filename： 模块名
 * permanent： 是否永久，0为当前到关机前防卸载，1为永久防卸载。
 * return NSU_OK表示成功，其他值表示出现错误。
*/
int add_kmodpro_rule(char *kmodname, int permanent);
/*
 * 将一个网络进程加入到保护列表中，不允许该进程连接网络。
 * filename： 进程路径
 * permanent： 是否永久，0为当前到关机前禁止联网，1为永久禁止。
 * return NSU_OK表示成功，其他值表示出现错误。
*/
int add_netpro_rule(char *filename, int permanent);

int del_ppro_rule(char *filename, int permanent);
int del_fpro_rule(char *filename);
int del_kmodpro_rule(char *kmodname, int permanent);
int del_netpro_rule(char *filename, int permanent);



#endif /* __NFS_SECURITY_UTILES_H */
