#ifndef _SECURITY_STATUS_H_
#define _SECURITY_STATUS_H_

#define SELINUX_DISABLED 0
#define SELINUX_ENFORCING 1
#define SELINUX_PERMISSIVE 2

#define STATUS_DISABLE 0
#define STATUS_ENABLE 1

/********************************************************
* Function name : get_ternaryuser_status
* Description   : Get ternary user status
* Return : STATUS_DISABLE -- disable , STATUS_ENABLE -- enable
**********************************************************/
int get_ternaryuser_status();

/********************************************************
* Function name : get_devicecontrol_status
* Description   : Get peripheral protection status
* Return : STATUS_DISABLE -- disable , STATUS_ENABLE -- enable
**********************************************************/
int get_devicecontrol_status();

/********************************************************
* Function name : get_systemsecurityprotect_status
* Description   : Get system security protection status
* Return : STATUS_DISABLE -- disable , STATUS_ENABLE -- enable
**********************************************************/
int get_systemsecurityprotect_status();

/********************************************************
* Function name : get_packageprotect_status
* Description   : Get packet protection status
* Return : STATUS_DISABLE -- disable , STATUS_ENABLE -- enable
**********************************************************/
int get_packageprotect_status();

/********************************************************
* Function name : get_sestatus
* Description   : Get Selinux status
* Return        : 
*     SELINUX_PERMISSIVE -- SELinux prints warnings instead of enforcing.
*     SELINUX_ENFORCING  -- SELinux security policy is enforced.
*     SELINUX_DISABLED   -- No SELinux policy is loaded.
**********************************************************/
int get_sestatus();

/********************************************************
* Function name : get_imastatus
* Description   : Get IMA status
* Return : STATUS_DISABLE -- disable , STATUS_ENABLE -- enable
**********************************************************/
int get_imastatus();


/********************************************************
* Function name : set_ternaryuser_status
* Description   : Set ternary user status
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_ternaryuser_status(int status);

/********************************************************
* Function name : set_devicecontrol_status
* Description   : Set peripheral protection status
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_devicecontrol_status(int status);

/********************************************************
* Function name : set_systemsecurityprotect_status
* Description   : Set system security protection status
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_systemsecurityprotect_status(int status);

/********************************************************
* Function name : set_packageprotect_status
* Description   : Set packet protection status
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_packageprotect_status(int status);

/********************************************************
* Function name : set_selinux_status
* Description   : Set Selinux status
* Parameter     ：
*   @status The state you want to set: SELINUX_PERMISSIVE、SELINUX_ENFORCING or SELINUX_DISABLED
* Return        ：0 --success , other -- fail
**********************************************************/
int set_selinux_status(int status);

/********************************************************
* Function name : set_ima_status
* Description   : Set IMA status
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_ima_status(int status);

/********************************************************
* Function name : set_audit_status
* Description   : Set the Audit status when ternaryuser is STATUS_DISABLE.
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_audit_status(int status);

/********************************************************
* Function name : set_bootmeasure_status
* Description   : Set the Boot Measure status .
* Parameter     ：
*   @status The state you want to set: STATUS_DISABLE or STATUS_ENABLE
* Return        ：0 --success , other -- fail
**********************************************************/
int set_bootmeasure_status(int status);

#endif
